@@ -123,12 +123,12 @@ perform operation non-blocking.
 =head2 command
 
   my $doc = $db->command(bson_doc(getLastError => 1, w => 2));
-  my $doc = $db->command('getLastError', {w => 2});
+  my $doc = $db->command('getLastError', w => 2);
 
 Run command against database. You can also append a callback to run command
 non-blocking.
 
-  $db->command(('getLastError', {w => 2}) => sub {
+  $db->command(('getLastError', w => 2) => sub {
     my ($db, $err, $doc) = @_;
     ...
   });
